<?php

namespace Litecms\Voucher\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litecms\Voucher\Http\Requests\VoucherRequest;
use Litecms\Voucher\Interfaces\VoucherRepositoryInterface;
use Litecms\Voucher\Models\Voucher;
use Litecms\Voucher\Forms\Voucher as Form;

/**
 * APIController  class for voucher.
 */
class VoucherAPIController extends BaseController
{

    /**
     * Initialize voucher resource controller.
     *
     * @param type VoucherRepositoryInterface $voucher
     *
     * @return null
     */
    public function __construct(VoucherRepositoryInterface $voucher)
    {
        parent::__construct();
        $this->repository = $voucher;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Voucher\Repositories\Criteria\VoucherResourceCriteria::class);
    }

    /**
     * Display a list of voucher.
     *
     * @return Response
     */
    public function index(VoucherRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litecms\Voucher\Repositories\Presenter\VoucherPresenter::class)
            ->paginate();
    }

    /**
     * Display voucher.
     *
     * @param Request $request
     * @param Model   $voucher
     *
     * @return Response
     */
    public function show(VoucherRequest $request, Voucher $voucher)
    {
        return $voucher->setPresenter(\Litecms\Voucher\Repositories\Presenter\VoucherListPresenter::class);
        ;
    }

    /**
     * Create new voucher.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(VoucherRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('voucher::voucher.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('voucher/voucher/' . $voucher->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('voucher/voucher');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the voucher.
     *
     * @param Request $request
     * @param Model   $voucher
     *
     * @return Response
     */
    public function update(VoucherRequest $request, Voucher $voucher)
    {
        try {
            $data = $request->all();

            $voucher->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('voucher::voucher.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('voucher/voucher/' . $voucher->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('voucher/voucher/' . $voucher->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the voucher.
     *
     * @param Model   $voucher
     *
     * @return Response
     */
    public function destroy(VoucherRequest $request, Voucher $voucher)
    {
        try {
            $voucher->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('voucher::voucher.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('voucher/voucher/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('voucher/voucher/' . $voucher->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
