<?php

namespace Litecms\Voucher\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\Voucher\Http\Requests\VoucherRequest;
use Litecms\Voucher\Models\Voucher;

/**
 * Admin web controller class.
 */
class VoucherWorkflowController extends BaseController
{

    /**
     * Workflow controller function for voucher.
     *
     * @param Model   $voucher
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(VoucherRequest $request, Voucher $voucher, $step)
    {

        try {

            $voucher->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('voucher::voucher.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/voucher/voucher/' . $voucher->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/voucher/voucher/' . $voucher->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for voucher.
     *
     * @param Model   $voucher
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Voucher $voucher, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $voucher->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('voucher::voucher.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('voucher::admin.voucher.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('voucher::admin.voucher.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('voucher::admin.voucher.message', $data)->render();

        }

    }
}
