<?php

namespace Litecms\Voucher\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Voucher\Models\Voucher;

class VoucherPolicy
{

    /**
     * Determine if the given user can view the voucher.
     *
     * @param UserPolicy $user
     * @param Voucher $voucher
     *
     * @return bool
     */
    public function view(UserPolicy $user, Voucher $voucher)
    {
        if ($user->canDo('voucher.voucher.view') && $user->isAdmin()) {
            return true;
        }

        return $voucher->user_id == user_id() && $voucher->user_type == user_type();
    }

    /**
     * Determine if the given user can create a voucher.
     *
     * @param UserPolicy $user
     * @param Voucher $voucher
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('voucher.voucher.create');
    }

    /**
     * Determine if the given user can update the given voucher.
     *
     * @param UserPolicy $user
     * @param Voucher $voucher
     *
     * @return bool
     */
    public function update(UserPolicy $user, Voucher $voucher)
    {
        if ($user->canDo('voucher.voucher.edit') && $user->isAdmin()) {
            return true;
        }

        return $voucher->user_id == user_id() && $voucher->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given voucher.
     *
     * @param UserPolicy $user
     * @param Voucher $voucher
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Voucher $voucher)
    {
        return $voucher->user_id == user_id() && $voucher->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given voucher.
     *
     * @param UserPolicy $user
     * @param Voucher $voucher
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Voucher $voucher)
    {
        if ($user->canDo('voucher.voucher.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given voucher.
     *
     * @param UserPolicy $user
     * @param Voucher $voucher
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Voucher $voucher)
    {
        if ($user->canDo('voucher.voucher.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
