<?php

namespace Litecms\Voucher\Providers;

use Illuminate\Support\ServiceProvider;

class VoucherServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'voucher');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'voucher');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerVoucher();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerVoucher()
    {
        $this->app->bind('voucher', function($app) {
            return new Voucher($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Voucher', 'Lavalite\Voucher\Facades\Voucher');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litecms.voucher', function ($app) {
            return $this->app->make('Litecms\Voucher\Voucher');
        });

                // Bind Voucher to repository
        $this->app->bind(
            'Litecms\Voucher\Interfaces\VoucherRepositoryInterface',
            \Litecms\Voucher\Repositories\Eloquent\VoucherRepository::class
        );

        $this->app->register(\Litecms\Voucher\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Voucher\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Voucher\Providers\RouteServiceProvider::class);
                // $this->app->register(\Litecms\Voucher\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and voucher's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.voucher'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeVoucher::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.voucher'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/voucher.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/voucher')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/voucher')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
