<?php

namespace Litecms\Voucher\Workflow;

use Litecms\Voucher\Models\Voucher;
use Validator;

class VoucherValidator
{

    /**
     * Determine if the given voucher is valid for complete status.
     *
     * @param Voucher $voucher
     *
     * @return bool / Validator
     */
    public function complete(Voucher $voucher)
    {
        return Validator::make($voucher->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given voucher is valid for verify status.
     *
     * @param Voucher $voucher
     *
     * @return bool / Validator
     */
    public function verify(Voucher $voucher)
    {
        return Validator::make($voucher->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given voucher is valid for approve status.
     *
     * @param Voucher $voucher
     *
     * @return bool / Validator
     */
    public function approve(Voucher $voucher)
    {
        return Validator::make($voucher->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given voucher is valid for publish status.
     *
     * @param Voucher $voucher
     *
     * @return bool / Validator
     */
    public function publish(Voucher $voucher)
    {
        return Validator::make($voucher->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given voucher is valid for archive status.
     *
     * @param Voucher $voucher
     *
     * @return bool / Validator
     */
    public function archive(Voucher $voucher)
    {
        return Validator::make($voucher->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given voucher is valid for unpublish status.
     *
     * @param Voucher $voucher
     *
     * @return bool / Validator
     */
    public function unpublish(Voucher $voucher)
    {
        return Validator::make($voucher->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
